BcGoldenConfiguration class Configuration
BcGoldenConfiguration
This class contains all the configuration that uses the tests to run. For example the themes that the app uses could be configured in here.
Constructors
- BcGoldenConfiguration()
-
factory
Properties
- goldenDifferenceThreshold ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeData ↔ ThemeData?
-
themeData is the data object that defines the theme for the application.
getter/setter pair
-
themeProvider
↔ List<
SingleChildWidget> ? -
themeProvider is a list of widgets that provide theme-related functionality.
getter/setter pair
- willFailOnError ↔ bool
-
goldenDifferenceThreshold is the threshold value for determining the difference
between golden images and actual images, defaulting to 10.
willFailOnError indicates whether the process should fail when an error occurs,
defaulting to true.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited