GoldenAnimationStep class Configuration
GoldenAnimationStep
Represents a specific frame in an animation timeline to be captured.
This class defines when to capture a frame during an animation and allows for optional setup and verification actions at that specific timestamp.
- timestamp The exact time in the animation when this frame should be captured in ms.
- frameName A descriptive name for this frame (e.g., "start", "peak", "end").
- setupAction Optional function to execute before capturing this frame.
- verifyAction Optional function to verify the state after capturing this frame.
Constructors
-
GoldenAnimationStep({required Duration timestamp, required String frameName, Future<
void> setupAction(WidgetTester)?, Future<void> verifyAction(WidgetTester)?}) -
const
Properties
- frameName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setupAction
→ Future<
void> Function(WidgetTester)? -
final
- timestamp → Duration
-
final
-
verifyAction
→ Future<
void> Function(WidgetTester)? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited